@@ -23,26 +23,26 @@
 
 #include "ui_configdialog.h"
 
-#include <KDialog>
+#include <QDialog>
 
 class KConfigDialogManager;
 
-class ConfigDialog : public KDialog
+class ConfigDialog : public QDialog
 {
-  Q_OBJECT
-  public:
-    ConfigDialog( QWidget *parent = 0 );
+    Q_OBJECT
+public:
+    explicit ConfigDialog(QWidget *parent = Q_NULLPTR);
     ~ConfigDialog();
 
-  private slots:
+private Q_SLOTS:
     void save();
 
-  private:
+private:
     void loadTags();
     void readConfig();
     void writeConfig();
     Ui::ConfigDialog ui;
-    KConfigDialogManager* mManager;
+    KConfigDialogManager *mManager;
 };
 
 #endif
