@@ -43,8 +43,8 @@ private Q_SLOTS:
         QList<QByteArray> scenario;
         QStringList callNames;
 
-        collection = createCollectionChain(QLatin1String("/INBOX/Foo"));
-        collection.attribute<UidValidityAttribute>(Akonadi::Entity::AddIfMissing)->setUidValidity(1149151135);
+        collection = createCollectionChain(QStringLiteral("/INBOX/Foo"));
+        collection.attribute<UidValidityAttribute>(Akonadi::Collection::AddIfMissing)->setUidValidity(1149151135);
 
         scenario.clear();
         scenario << defaultPoolConnectionScenario()
@@ -85,8 +85,8 @@ private Q_SLOTS:
                              << Akonadi::MessagePart::Header
                              << Akonadi::MessagePart::Body);
 
-        collection = createCollectionChain(QLatin1String("/INBOX/Foo"));
-        collection.attribute<UidValidityAttribute>(Akonadi::Entity::AddIfMissing)->setUidValidity(1149151135);
+        collection = createCollectionChain(QStringLiteral("/INBOX/Foo"));
+        collection.attribute<UidValidityAttribute>(Akonadi::Collection::AddIfMissing)->setUidValidity(1149151135);
         collection.setCachePolicy(policy);
 
         scenario.clear();
@@ -125,8 +125,8 @@ private Q_SLOTS:
         Akonadi::CollectionStatistics stats;
         stats.setCount(1);
 
-        collection = createCollectionChain(QLatin1String("/INBOX/Foo"));
-        collection.attribute<UidValidityAttribute>(Akonadi::Entity::AddIfMissing)->setUidValidity(1149151135);
+        collection = createCollectionChain(QStringLiteral("/INBOX/Foo"));
+        collection.attribute<UidValidityAttribute>(Akonadi::Collection::AddIfMissing)->setUidValidity(1149151135);
         collection.attribute<UidNextAttribute>(Akonadi::Collection::AddIfMissing)->setUidNext(9);
         collection.setCachePolicy(policy);
         collection.setStatistics(stats);
@@ -158,8 +158,8 @@ private Q_SLOTS:
         //Disabled test since the flag sync is disabled if CONDSTORE is not supported
 //     QTest::newRow( "second listing, checking for flag changes" ) << collection << scenario << callNames;
 
-        collection = createCollectionChain(QLatin1String("/INBOX/Foo"));
-        collection.attribute<UidValidityAttribute>(Akonadi::Entity::AddIfMissing)->setUidValidity(1149151135);
+        collection = createCollectionChain(QStringLiteral("/INBOX/Foo"));
+        collection.attribute<UidValidityAttribute>(Akonadi::Collection::AddIfMissing)->setUidValidity(1149151135);
         collection.setCachePolicy(policy);
         stats.setCount(1);
         collection.setStatistics(stats);
@@ -186,7 +186,7 @@ private Q_SLOTS:
         collection.attribute<UidNextAttribute>(Akonadi::Collection::AddIfMissing)->setUidNext(8);
         stats.setCount(4);
         collection.setStatistics(stats);
-        collection.attribute<HighestModSeqAttribute>(Akonadi::Entity::AddIfMissing)->setHighestModSeq(123456788);
+        collection.attribute<HighestModSeqAttribute>(Akonadi::Collection::AddIfMissing)->setHighestModSeq(123456788);
         scenario.clear();
         scenario << defaultPoolConnectionScenario()
                  << "C: A000003 SELECT \"INBOX/Foo\""
@@ -285,11 +285,11 @@ private Q_SLOTS:
         //A new message has been added and an old one removed, we can't do an incremental update
         QTest::newRow("uidnext changed, fetch new messages and list flags") << collection << scenario << callNames;
 
-        collection = createCollectionChain(QLatin1String("/INBOX/Foo"));
-        collection.attribute<UidValidityAttribute>(Akonadi::Entity::AddIfMissing)->setUidValidity(1149151135);
+        collection = createCollectionChain(QStringLiteral("/INBOX/Foo"));
+        collection.attribute<UidValidityAttribute>(Akonadi::Collection::AddIfMissing)->setUidValidity(1149151135);
         collection.setCachePolicy(policy);
         collection.attribute<UidNextAttribute>(Akonadi::Collection::AddIfMissing)->setUidNext(9);
-        collection.attribute<HighestModSeqAttribute>(Akonadi::Entity::AddIfMissing)->setHighestModSeq(123456789);
+        collection.attribute<HighestModSeqAttribute>(Akonadi::Collection::AddIfMissing)->setHighestModSeq(123456789);
         stats.setCount(5);
         collection.setStatistics(stats);
         scenario.clear();
@@ -313,11 +313,11 @@ private Q_SLOTS:
         //No flags have changed
         QTest::newRow("highestmodseq test") << collection << scenario << callNames;
 
-        collection = createCollectionChain(QLatin1String("/INBOX/Foo"));
-        collection.attribute<UidValidityAttribute>(Akonadi::Entity::AddIfMissing)->setUidValidity(1149151135);
+        collection = createCollectionChain(QStringLiteral("/INBOX/Foo"));
+        collection.attribute<UidValidityAttribute>(Akonadi::Collection::AddIfMissing)->setUidValidity(1149151135);
         collection.setCachePolicy(policy);
         collection.attribute<UidNextAttribute>(Akonadi::Collection::AddIfMissing)->setUidNext(9);
-        collection.attribute<HighestModSeqAttribute>(Akonadi::Entity::AddIfMissing)->setHighestModSeq(123456788);
+        collection.attribute<HighestModSeqAttribute>(Akonadi::Collection::AddIfMissing)->setHighestModSeq(123456788);
         stats.setCount(5);
         collection.setStatistics(stats);
         scenario.clear();
@@ -344,11 +344,11 @@ private Q_SLOTS:
         //fetch only changed flags
         QTest::newRow("changedsince test") << collection << scenario << callNames;
 
-        collection = createCollectionChain(QLatin1String("/INBOX/Foo"));
+        collection = createCollectionChain(QStringLiteral("/INBOX/Foo"));
         collection.setCachePolicy(policy);
-        collection.attribute<UidValidityAttribute>(Akonadi::Entity::AddIfMissing)->setUidValidity(1149151135);
+        collection.attribute<UidValidityAttribute>(Akonadi::Collection::AddIfMissing)->setUidValidity(1149151135);
         collection.attribute<UidNextAttribute>(Akonadi::Collection::AddIfMissing)->setUidNext(9);
-        collection.attribute<HighestModSeqAttribute>(Akonadi::Entity::AddIfMissing)->setHighestModSeq(123456788);
+        collection.attribute<HighestModSeqAttribute>(Akonadi::Collection::AddIfMissing)->setHighestModSeq(123456788);
         stats.setCount(5);
         collection.setStatistics(stats);
         scenario.clear();
@@ -381,9 +381,9 @@ private Q_SLOTS:
         //Don't rely on yahoos highestmodseq implementation
         QTest::newRow("yahoo highestmodseq test") << collection << scenario << callNames;
 
-        collection = createCollectionChain(QLatin1String("/INBOX/Foo"));
+        collection = createCollectionChain(QStringLiteral("/INBOX/Foo"));
         collection.attribute<UidNextAttribute>(Akonadi::Collection::AddIfMissing)->setUidNext(9);
-        collection.attribute<UidValidityAttribute>(Akonadi::Entity::AddIfMissing)->setUidValidity(3);
+        collection.attribute<UidValidityAttribute>(Akonadi::Collection::AddIfMissing)->setUidValidity(3);
         collection.setCachePolicy(policy);
         stats.setCount(1);
         collection.setStatistics(stats);
@@ -421,9 +421,9 @@ private Q_SLOTS:
 
         QTest::newRow("uidvalidity changed") << collection << scenario << callNames;
 
-        collection = createCollectionChain(QLatin1String("/INBOX/Foo"));
+        collection = createCollectionChain(QStringLiteral("/INBOX/Foo"));
         collection.attribute<UidNextAttribute>(Akonadi::Collection::AddIfMissing)->setUidNext(105);
-        collection.attribute<UidValidityAttribute>(Akonadi::Entity::AddIfMissing)->setUidValidity(1149151135);
+        collection.attribute<UidValidityAttribute>(Akonadi::Collection::AddIfMissing)->setUidValidity(1149151135);
         collection.setCachePolicy(policy);
         stats.setCount(104);
         collection.setStatistics(stats);
@@ -481,11 +481,11 @@ private Q_SLOTS:
 
         QTest::newRow("test batch processing") << collection << scenario << callNames;
 
-        collection = createCollectionChain(QLatin1String("/INBOX/Foo"));
-        collection.attribute<UidValidityAttribute>(Akonadi::Entity::AddIfMissing)->setUidValidity(1149151135);
+        collection = createCollectionChain(QStringLiteral("/INBOX/Foo"));
+        collection.attribute<UidValidityAttribute>(Akonadi::Collection::AddIfMissing)->setUidValidity(1149151135);
         collection.setCachePolicy(policy);
         collection.attribute<UidNextAttribute>(Akonadi::Collection::AddIfMissing)->setUidNext(9);
-        collection.attribute<HighestModSeqAttribute>(Akonadi::Entity::AddIfMissing)->setHighestModSeq(123456789);
+        collection.attribute<HighestModSeqAttribute>(Akonadi::Collection::AddIfMissing)->setHighestModSeq(123456789);
         stats.setCount(5);
         collection.setStatistics(stats);
         scenario.clear();
@@ -518,11 +518,11 @@ private Q_SLOTS:
         //fetch only changed flags
         QTest::newRow("remote message deleted") << collection << scenario << callNames;
 
-        collection = createCollectionChain(QLatin1String("/INBOX/Foo"));
-        collection.attribute<UidValidityAttribute>(Akonadi::Entity::AddIfMissing)->setUidValidity(1149151135);
+        collection = createCollectionChain(QStringLiteral("/INBOX/Foo"));
+        collection.attribute<UidValidityAttribute>(Akonadi::Collection::AddIfMissing)->setUidValidity(1149151135);
         collection.setCachePolicy(policy);
         collection.attribute<UidNextAttribute>(Akonadi::Collection::AddIfMissing)->setUidNext(-1);
-        collection.attribute<HighestModSeqAttribute>(Akonadi::Entity::AddIfMissing)->setHighestModSeq(123456789);
+        collection.attribute<HighestModSeqAttribute>(Akonadi::Collection::AddIfMissing)->setHighestModSeq(123456789);
         stats.setCount(0);
         collection.setStatistics(stats);
         scenario.clear();
