@@ -74,10 +74,10 @@ void RetrieveCollectionMetadataTask::doStart(KIMAP::Session *session)
     m_pendingMetaDataJobs = 0;
 
     // First get the annotations from the mailbox if it's supported
-    if (capabilities.contains(QLatin1String("METADATA")) || capabilities.contains(QLatin1String("ANNOTATEMORE"))) {
+    if (capabilities.contains(QStringLiteral("METADATA")) || capabilities.contains(QStringLiteral("ANNOTATEMORE"))) {
         KIMAP::GetMetaDataJob *meta = new KIMAP::GetMetaDataJob(session);
         meta->setMailBox(mailBox);
-        if (capabilities.contains(QLatin1String("METADATA"))) {
+        if (capabilities.contains(QStringLiteral("METADATA"))) {
             meta->setServerCapability(KIMAP::MetaDataJobBase::Metadata);
             meta->addRequestedEntry("/shared");
             meta->setDepth(KIMAP::GetMetaDataJob::AllLevels);
@@ -85,25 +85,25 @@ void RetrieveCollectionMetadataTask::doStart(KIMAP::Session *session)
             meta->setServerCapability(KIMAP::MetaDataJobBase::Annotatemore);
             meta->addEntry("*", "value.shared");
         }
-        connect(meta, SIGNAL(result(KJob*)), SLOT(onGetMetaDataDone(KJob*)));
+        connect(meta, &KJob::result, this, &RetrieveCollectionMetadataTask::onGetMetaDataDone);
         m_pendingMetaDataJobs++;
         meta->start();
     }
 
     // Get the ACLs from the mailbox if it's supported
-    if (capabilities.contains(QLatin1String("ACL"))) {
+    if (capabilities.contains(QStringLiteral("ACL"))) {
         KIMAP::MyRightsJob *rights = new KIMAP::MyRightsJob(session);
         rights->setMailBox(mailBox);
-        connect(rights, SIGNAL(result(KJob*)), SLOT(onRightsReceived(KJob*)));
+        connect(rights, &KJob::result, this, &RetrieveCollectionMetadataTask::onRightsReceived);
         m_pendingMetaDataJobs++;
         rights->start();
     }
 
     // Get the QUOTA info from the mailbox if it's supported
-    if (capabilities.contains(QLatin1String("QUOTA"))) {
+    if (capabilities.contains(QStringLiteral("QUOTA"))) {
         KIMAP::GetQuotaRootJob *quota = new KIMAP::GetQuotaRootJob(session);
         quota->setMailBox(mailBox);
-        connect(quota, SIGNAL(result(KJob*)), SLOT(onQuotasReceived(KJob*)));
+        connect(quota, &KJob::result, this, &RetrieveCollectionMetadataTask::onQuotasReceived);
         m_pendingMetaDataJobs++;
         quota->start();
     }
@@ -216,7 +216,7 @@ void RetrieveCollectionMetadataTask::onRightsReceived(KJob *job)
     if (imapRights & KIMAP::Acl::Admin) {
         KIMAP::GetAclJob *acl = new KIMAP::GetAclJob(m_session);
         acl->setMailBox(mailBoxForCollection(m_collection));
-        connect(acl, SIGNAL(result(KJob*)), SLOT(onGetAclDone(KJob*)));
+        connect(acl, &KJob::result, this, &RetrieveCollectionMetadataTask::onGetAclDone);
         m_pendingMetaDataJobs++;
         acl->start();
     }
