@@ -87,7 +87,29 @@ public:
         mLastModified = lastModified;
     }
 
-    static RemoteInformation load(const Entity &entity)
+    static RemoteInformation load(const Item &item)
+    {
+        return loadImpl(item);
+    }
+
+    static RemoteInformation load(const Collection &collection)
+    {
+        return loadImpl(collection);
+    }
+
+    void store(Item &item) const
+    {
+        storeImpl(item);
+    }
+
+    void store(Collection &collection) const
+    {
+        storeImpl(collection);
+    }
+
+private:
+    template<typename T>
+    static inline RemoteInformation loadImpl(const T &entity)
     {
         const QStringList parts = entity.remoteRevision().split(QLatin1Char(':'), QString::KeepEmptyParts);
 
@@ -105,7 +127,7 @@ public:
             }
         }
 
-        QString lastModified = QLatin1String("0");
+        QString lastModified = QStringLiteral("0");
         if (parts.count() > 1) {
             lastModified = parts.at(1);
         }
@@ -113,7 +135,8 @@ public:
         return RemoteInformation(entity.remoteId().toLongLong(), module, lastModified);
     }
 
-    void store(Entity &entity) const
+    template<typename T>
+    inline void storeImpl(T &entity) const
     {
         QString module;
         switch (mModule) {
@@ -135,10 +158,9 @@ public:
         parts.append(mLastModified);
 
         entity.setRemoteId(QString::number(mObjectId));
-        entity.setRemoteRevision(parts.join(QLatin1String(":")));
+        entity.setRemoteRevision(parts.join(QStringLiteral(":")));
     }
 
-private:
     qlonglong mObjectId;
     OXA::Folder::Module mModule;
     QString mLastModified;
@@ -169,7 +191,7 @@ public:
             pairs.append(QString::number(it.key()) + QLatin1Char('=') + QString::number(it.value()));
         }
 
-        Settings::self()->setObjectsLastSync(pairs.join(QLatin1String(":")));
+        Settings::self()->setObjectsLastSync(pairs.join(QStringLiteral(":")));
         Settings::self()->save();
     }
 
@@ -258,7 +280,7 @@ OpenXchangeResource::OpenXchangeResource(const QString &id)
     mResourceCollection.setContentMimeTypes(QStringList() << Collection::mimeType());
     mResourceCollection.setRights(Collection::ReadOnly);
     EntityDisplayAttribute *attribute = mResourceCollection.attribute<EntityDisplayAttribute>(Collection::AddIfMissing);
-    attribute->setIconName(QLatin1String("ox"));
+    attribute->setIconName(QStringLiteral("ox"));
 
     Collection privateFolder;
     privateFolder.setParentCollection(mResourceCollection);
@@ -336,7 +358,7 @@ void OpenXchangeResource::configure(WId windowId)
     const bool useIncrementalUpdates = Settings::self()->useIncrementalUpdates();
 
     ConfigDialog dlg(windowId);
-    dlg.setWindowIcon(QIcon::fromTheme("ox"));
+    dlg.setWindowIcon(QIcon::fromTheme(QStringLiteral("ox")));
     if (dlg.exec()) {   //krazy:exclude=crashy
 
         // if the user has changed the incremental update settings we have to do
@@ -894,7 +916,7 @@ static Collection folderToCollection(const OXA::Folder &folder, const Collection
     remoteInformation.store(collection);
 
     // set a unique name to make Akonadi happy
-    collection.setName(folder.title() + '_' + QUuid::createUuid().toString());
+    collection.setName(folder.title() + QLatin1Char('_') + QUuid::createUuid().toString());
 
     EntityDisplayAttribute *attribute = collection.attribute<EntityDisplayAttribute>(Collection::AddIfMissing);
     attribute->setDisplayName(folder.title());
