@@ -27,23 +27,24 @@
 #include "folder.h"
 #include "object.h"
 
-namespace OXA {
+namespace OXA
+{
 
 class ObjectMoveJob : public KJob
 {
-  Q_OBJECT
+    Q_OBJECT
 
-  public:
-    ObjectMoveJob( const Object &object, const Folder &destinationFolder, QObject *parent = 0 );
+public:
+    ObjectMoveJob(const Object &object, const Folder &destinationFolder, QObject *parent = Q_NULLPTR);
 
-    virtual void start();
+    void start() Q_DECL_OVERRIDE;
 
     Object object() const;
 
-  private Q_SLOTS:
-    void davJobFinished( KJob* );
+private Q_SLOTS:
+    void davJobFinished(KJob *);
 
-  private:
+private:
     Object mObject;
     Folder mDestinationFolder;
 };
