@@ -50,7 +50,7 @@ class AKONADI_SINGLEFILERESOURCE_EXPORT SingleFileResource : public SingleFileRe
 public:
     SingleFileResource(const QString &id)
         : SingleFileResourceBase(id)
-        , mSettings(new Settings(componentData().config()))
+        , mSettings(new Settings(config()))
     {
         // The resource needs network when the path refers to a non local file.
         setNeedsNetwork(!QUrl(mSettings->path()).isLocalFile());
@@ -284,7 +284,7 @@ public:
         }
     }
 
-    virtual void collectionChanged(const Collection &collection) Q_DECL_OVERRIDE {
+    void collectionChanged(const Collection &collection) Q_DECL_OVERRIDE {
         QString newName;
         if (collection.hasAttribute<EntityDisplayAttribute>())
         {
@@ -300,7 +300,7 @@ public:
         SingleFileResourceBase::collectionChanged(collection);
     }
 
-    virtual Collection rootCollection() const Q_DECL_OVERRIDE
+    Collection rootCollection() const Q_DECL_OVERRIDE
     {
         Collection c;
         c.setParentCollection(Collection::root());
